@@ -473,3 +473,19 @@ class VariableClInstallKernelBuild(Variable):
     Переменная используемся для GRP дистрибутивов и сборки нескольких ядер
     """
     value = ""
+
+
+class VariableClInstallKernelVersion(VariableOsInstallKernelConfig):
+    """
+    Версия ядра в /usr/src/linux
+    """
+    def get(self):
+        image = self.Get('cl_image')
+        if image:
+            with image:
+                try:
+                    distrPath = image.getDirectory()
+                    return self.get_kernel_src(distrPath)
+                except DistributiveError as e:
+                    return ""
+        return ""
