@@ -77,7 +77,9 @@ class Wsdl(WsdlBase):
                                         'cl_image_new_only')),
             lambda group: group(_("Allocate drive space"),
                                 normal=('cl_autopartition_set',),
-                                hide=('cl_autopartition_set',),
+                                hide=('cl_autopartition_set',
+                                      'cl_autopartition_root_size',
+                                      'cl_autopartition_swap_size',),
                                 brief=('cl_autopartition_brief_set',),
                                 expert=('cl_autopartition_scheme',
                                         'cl_autopartition_table',
@@ -127,7 +129,7 @@ class Wsdl(WsdlBase):
                                         'cl_install_cleanpkg_set',
                                         'cl_install_other_set'))],
         # действие выводит информацию перед запуском
-        'brief': {'next': __("Perform"),
+        'brief': {'next': __("Run"),
                   'image': 'finish',
                   'name': __("Start installing")}},
         # установка на Flash
@@ -135,7 +137,8 @@ class Wsdl(WsdlBase):
             'method_name': "install_flash",
             'category': __("Installation"),
             'title': __("Flash Install"),
-            'image': ('drive-removable-media-usb-pendrive,'
+            'image': ('calculate-install-flash,'
+                      'drive-removable-media-usb-pendrive,'
                       'drive-removable-media-usb,media-flash'),
             'command': 'cl-install-flash',
             'gui': True,
@@ -147,21 +150,23 @@ class Wsdl(WsdlBase):
                              DataVarsError, install.InstallError),
             'setvars': {'cl_action!': 'system', 'cl_install_type': 'flash',
                         'cl_protect_use_set!': 'off',
+                        'cl_autopartition_set!': 'off',
                         'cl_dispatch_conf': 'usenew'},
             'groups': [
                 lambda group: group(_("Flash install"),
                                     normal=('cl_image_filename',
                                             'os_install_disk_single',
                                             'os_install_format_single_set'),
-                                    next_label=_("Perform"))],
-            'brief': {'next': __("Perform"),
+                                    next_label=_("Run"))],
+            'brief': {'next': __("Run"),
                       'name': __("Start installing")}},
         # PXE установка
         {
             'method_name': "install_pxe",
             'category': __("Installation"),
             'title': __("PXE Install"),
-            'image': ('gnome-network-properties,network-server,'
+            'image': ('calculate-install-pxe,gnome-network-properties,'
+                      'network-server,'
                       'preferences-desktop-remote-desktop'),
             'command': 'cl-install-pxe',
             'gui': True,
@@ -183,13 +188,13 @@ class Wsdl(WsdlBase):
                                     normal=('cl_image_filename',),
                                     expert=('os_install_pxe_path',
                                             'os_install_pxe_ip'),
-                                    next_label=_("Perform"))]},
+                                    next_label=_("Run"))]},
         # настройка загрузки системы
         {
             'method_name': "setup_boot",
             'category': __("Configuration"),
             'title': __("Boot"),
-            'image': 'stock_save,drive-harddisk',
+            'image': 'calculate-setup-boot,stock_save,drive-harddisk',
             'command': 'cl-setup-boot',
             'gui': True,
             'rights': ['setupboot'],
@@ -216,7 +221,7 @@ class Wsdl(WsdlBase):
             'method_name': "setup_network",
             'category': __("Configuration"),
             'title': __("Network"),
-            'image': 'network-workgroup,'
+            'image': 'calculate-setup-network,network-workgroup,'
                      'network-idle,preferences-system-network',
             'command': 'cl-setup-network',
             'gui': True,
@@ -246,7 +251,8 @@ class Wsdl(WsdlBase):
             'method_name': "setup_system",
             'category': __("Configuration"),
             'title': __("System"),
-            'image': 'run-build,applications-ide,system-run,system,computer',
+            'image': 'calculate-setup-system,run-build,applications-ide,'
+                     'system-run,system,computer',
             'command': 'cl-setup-system',
             'gui': True,
             'rights': ['setupsystem'],
@@ -269,7 +275,8 @@ class Wsdl(WsdlBase):
             'method_name': "setup_video",
             'category': __("Configuration"),
             'title': __("Video"),
-            'image': 'system-config-display,video-display,gnome-multimedia',
+            'image': 'calculate-setup-video,system-config-display,'
+                     'video-display,gnome-multimedia',
             'command': 'cl-setup-video',
             'gui': True,
             'rights': ['setupvideo'],
@@ -296,7 +303,7 @@ class Wsdl(WsdlBase):
             'method_name': "setup_audio",
             'category': __("Configuration"),
             'title': __("Audio"),
-            'image': 'audio-card',
+            'image': 'calculate-setup-audio,audio-card',
             'command': 'cl-setup-audio',
             'gui': True,
             'rights': ['setupaudio'],
@@ -321,7 +328,7 @@ class Wsdl(WsdlBase):
             'method_name': "setup_locale",
             'category': __("Configuration"),
             'title': __("Locale"),
-            'image': 'locale,preferences-desktop-locale',
+            'image': 'calculate-setup-locale,locale,preferences-desktop-locale',
             'command': 'cl-setup-locale',
             'gui': True,
             'rights': ['setuplocale'],
@@ -346,7 +353,7 @@ class Wsdl(WsdlBase):
             'method_name': "setup_session",
             'category': __("Configuration"),
             'title': __("Session"),
-            'image': 'system-lock-screen',
+            'image': 'calculate-setup-session,system-lock-screen',
             'command': 'cl-setup-session',
             'gui': True,
             'rights': ['setupsession'],
